@@ -10,6 +10,7 @@ from keras.layers.advanced_activations import LeakyReLU
 from keras.models import Model, model_from_json
 from keras.utils import to_categorical
 from keras.utils.generic_utils import get_custom_objects
+from keras import backend as K
 from scipy import sparse
 
 from scarches.models._activations import ACTIVATIONS
@@ -69,18 +70,19 @@ class CVAE(object):
         self.lr = kwargs.get("learning_rate", 0.001)
         self.alpha = kwargs.get("alpha", 0.0001)
         self.eta = kwargs.get("eta", 1.0)
-        self.dr_rate = kwargs.get("dropout_rate", 0.05)
+        self.dr_rate = kwargs.get("dropout_rate", 0.1)
         self.model_path = os.path.join(kwargs.get("model_path", "./models/CVAE/"), self.task_name)
-        self.loss_fn = kwargs.get("loss_fn", 'mse')
+        self.loss_fn = kwargs.get("loss_fn", 'nb')
         self.ridge = kwargs.get('ridge', 0.1)
         self.scale_factor = kwargs.get("scale_factor", 1.0)
         self.clip_value = kwargs.get('clip_value', 3.0)
         self.epsilon = kwargs.get('epsilon', 0.01)
-        self.output_activation = kwargs.get("output_activation", 'relu')
+        self.output_activation = kwargs.get("output_activation", 'linear')
         self.use_batchnorm = kwargs.get("use_batchnorm", True)
-        self.architecture = kwargs.get("architecture", [128, 32])
+        self.architecture = kwargs.get("architecture", [128, 128])
         self.size_factor_key = kwargs.get("size_factor_key", 'size_factors')
-        self.device = kwargs.get("device", "cpu")
+        self.device = kwargs.get("device", "gpu") if len(K.tensorflow_backend._get_available_gpus()) > 0 else 'cpu'
+
         self.gene_names = kwargs.get("gene_names", None)
         self.model_name = kwargs.get("model_name", "cvae")
         self.class_name = kwargs.get("class_name", 'CVAE')
@@ -704,8 +706,8 @@ class CVAE(object):
 
     def train(self, adata,
               condition_key, train_size=0.8, cell_type_key='cell_type',
-              n_epochs=25, batch_size=32,
-              early_stop_limit=20, lr_reducer=10,
+              n_epochs=200, batch_size=128,
+              early_stop_limit=10, lr_reducer=8,
               n_per_epoch=0, score_filename=None,
               save=True, retrain=True, verbose=3):
 
@@ -748,8 +750,8 @@ class CVAE(object):
 
     def _fit(self, adata,
              condition_key, train_size=0.8, cell_type_key='cell_type',
-             n_epochs=25, batch_size=32,
-             early_stop_limit=20, lr_reducer=10,
+             n_epochs=100, batch_size=128,
+             early_stop_limit=10, lr_reducer=8,
              n_per_epoch=0, score_filename=None,
              save=True, retrain=True, verbose=3):
         train_adata, valid_adata = train_test_split(adata, train_size)
@@ -842,8 +844,8 @@ class CVAE(object):
 
     def _train_on_batch(self, adata,
                         condition_key, train_size=0.8, cell_type_key='cell_type',
-                        n_epochs=25, batch_size=32,
-                        early_stop_limit=20, lr_reducer=10,
+                        n_epochs=100, batch_size=128,
+                        early_stop_limit=10, lr_reducer=8,
                         n_per_epoch=0, score_filename=None,
                         save=True, retrain=True, verbose=3):
         train_adata, valid_adata = train_test_split(adata, train_size)
