@@ -50,7 +50,8 @@ class scArches(CVAE):
             `clip_value`: float
                 Optimizer's clip value used for clipping the computed gradients.
             `output_activation`: str
-                Output activation of scArches which Depends on the range of data.
+                Output activation of scArches which Depends on the range of data. For positive value you can use "relu" or "linear" but if your data
+                have negative value set to "linear" which is default.
             `use_batchnorm`: bool
                 Whether use batch normalization in scArches or not.
             `architecture`: list
@@ -72,7 +73,7 @@ class scArches(CVAE):
             return super(scArches, cls).__new__(cls)
 
     def __init__(self, x_dimension, conditions, task_name="unknown", z_dimension=10, **kwargs):
-        self.beta = kwargs.pop('beta', 20.0)
+        self.beta = kwargs.pop('beta', 0.0)
         self.mmd_computation_method = kwargs.pop("mmd_computation_method", "general")
 
         if kwargs.get("loss_fn", "mse") in ['nb', 'zinb']:
@@ -189,7 +190,7 @@ class scArches(CVAE):
                                'FirstLayer': LAYERS['FirstLayer']}
 
         get_custom_objects().update(self.custom_objects)
-        print(f"{self.class_name}'s network has been successfully constructed!")
+        print(f"{self.class_name}' network has been successfully constructed!")
 
     def _calculate_loss(self):
         """
@@ -258,7 +259,7 @@ class scArches(CVAE):
 
         return adata_mmd
 
-    def get_latent(self, adata, batch_key, return_z=False):
+    def get_latent(self, adata, batch_key, return_z=True):
         """ Transforms `adata` in latent space of scArches and returns the latent
         coordinates in the annotated (adata) format.
 
@@ -324,8 +325,8 @@ class scArches(CVAE):
 
     def _fit(self, adata,
              condition_key, train_size=0.8, cell_type_key='cell_type',
-             n_epochs=25, batch_size=32,
-             early_stop_limit=20, lr_reducer=10,
+             n_epochs=300, batch_size=512,
+             early_stop_limit=10, lr_reducer=7,
              n_per_epoch=0, score_filename=None,
              save=True, retrain=True, verbose=3):
         train_adata, valid_adata = train_test_split(adata, train_size)
@@ -407,8 +408,8 @@ class scArches(CVAE):
 
     def _train_on_batch(self, adata,
                         condition_key, train_size=0.8, cell_type_key='cell_type',
-                        n_epochs=25, batch_size=32,
-                        early_stop_limit=20, lr_reducer=10,
+                        n_epochs=300, batch_size=512,
+                        early_stop_limit=10, lr_reducer=7,
                         n_per_epoch=0, score_filename=None,
                         save=True, retrain=True, verbose=3):
         train_adata, valid_adata = train_test_split(adata, train_size)
@@ -457,7 +458,7 @@ class scArches(CVAE):
 
         es_patience, best_val_loss = 0, 1e10
         for i in range(n_epochs):
-            train_loss = train_recon_loss = train_kl_loss = 0.0
+            train_loss = train_recon_loss = train_mmd_loss = 0.0
             for j in range(min(500, train_adata.shape[0] // batch_size)):
                 batch_indices = np.random.choice(train_adata.shape[0], batch_size)
 
@@ -477,9 +478,9 @@ class scArches(CVAE):
 
                 train_loss += batch_loss / batch_size
                 train_recon_loss += batch_recon_loss / batch_size
-                train_kl_loss += batch_kl_loss / batch_size
+                train_mmd_loss += batch_kl_loss / batch_size
 
-            valid_loss, valid_recon_loss, valid_kl_loss = self.cvae_model.evaluate(x_valid, y_valid, verbose=0)
+            valid_loss, valid_recon_loss, valid_mmd_loss = self.cvae_model.evaluate(x_valid, y_valid, verbose=0)
 
             if valid_loss < best_val_loss:
                 best_val_loss = valid_loss
@@ -490,8 +491,8 @@ class scArches(CVAE):
                     print("Training stopped with Early Stopping")
                     break
 
-            logs = {"loss": train_loss, "recon_loss": train_recon_loss, "kl_loss": train_kl_loss,
-                    "val_loss": valid_loss, "val_recon_loss": valid_recon_loss, "val_kl_loss": valid_kl_loss}
+            logs = {"loss": train_loss, "recon_loss": train_recon_loss, "mmd_loss": train_mmd_loss,
+                    "val_loss": valid_loss, "val_recon_loss": valid_recon_loss, "val_mmd_loss": valid_mmd_loss}
             print_progress(i, logs, n_epochs)
 
         if save:
